﻿using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using System.Web.Mvc;
using Syncfusion.OfficeChart;
using System.Collections.Generic;
using System.Drawing;
using System;
using System.Data;
using System.Collections;

namespace CreateWordSample.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
           
            return View();
        }
        public ActionResult CreateDocument()
        {
            string input = Server.MapPath(@"..//Data//Graph 508 .docx").ToString();
			//Opens Word document
            WordDocument document = new WordDocument(input);
            foreach (WSection section in document.Sections)
            {
                //Accesses the Body of section where all the contents in document are apart
                WTextBody sectionBody = section.Body;
                IterateTextBody(sectionBody);
            }

            //Saves and closes the document instance
            document.Save("Result.docx", FormatType.Docx, HttpContext.ApplicationInstance.Response, HttpContentDisposition.Attachment);
            document.Close();

            return View();
        }
        /// <summary>
        /// Iterates into text body
        /// </summary>
        /// <param name="textBody"></param>
        private static void IterateTextBody(WTextBody textBody)
        {
            //Iterates through each of the child items of WTextBody
            for (int i = 0; i < textBody.ChildEntities.Count; i++)
            {
                //IEntity is the basic unit in DocIO DOM. 
                //Accesses the body items (should be either paragraph or table) as IEntity
                IEntity bodyItemEntity = textBody.ChildEntities[i];
                //A Text body has 2 types of elements - Paragraph and Table
                //Decides the element type by using EntityType
                switch (bodyItemEntity.EntityType)
                {
                    case EntityType.Paragraph:
                        //Gets paragraph from the section
                        WParagraph paragraph = bodyItemEntity as WParagraph;
                        foreach(Entity entity in paragraph.ChildEntities)
                        {
                            //Checks the entity is chart
                            if(entity is WChart)
                            {
                                //Gets chart from the document
                                WChart chart = entity as WChart;
                                chart.Series[0].SerieFormat.Fill.ForeColor = Color.Blue;
                                //Sets Fill pattern for each series
                                chart.Series[0].SerieFormat.Fill.Patterned(OfficeGradientPattern.Pat_Dark_Downward_Diagonal);
                                //Sets color for the chart
                                chart.Series[1].SerieFormat.Fill.ForeColor = Color.Orange;
                                //Sets Fill pattern for each series
                                chart.Series[1].SerieFormat.Fill.Patterned(OfficeGradientPattern.Pat_Dark_Downward_Diagonal);
                                //Sets color for the chart
                                chart.Series[2].SerieFormat.Fill.ForeColor = Color.Gray;
                                //Sets Fill pattern for each series
                                chart.Series[2].SerieFormat.Fill.Patterned(OfficeGradientPattern.Pat_Sphere);
                                //Sets color for the chart
                                chart.Series[3].SerieFormat.Fill.ForeColor = Color.Orange;
                                //Sets Fill pattern for each series
                                chart.Series[3].SerieFormat.Fill.Patterned(OfficeGradientPattern.Pat_Zig_Zag);
                                //Sets color for the chart
                                chart.Series[4].SerieFormat.Fill.ForeColor = Color.BlueViolet;
                                //Sets Fill pattern for each series
                                chart.Series[4].SerieFormat.Fill.Patterned(OfficeGradientPattern.Pat_Wide_Upward_Diagonal);
                            }
                        }
                        break;
                    case EntityType.Table:
                        //Table is a collection of rows and cells
                        //Iterates through table's DOM
                        IterateTable(bodyItemEntity as WTable);
                        break;
                }
            }
        }
        /// <summary>
        /// Iterates into table
        /// </summary>
        /// <param name="table"></param>
        private static void IterateTable(WTable table)
        {
            //Iterates the row collection in a table
            foreach (WTableRow row in table.Rows)
            {
                //Iterates the cell collection in a table row
                foreach (WTableCell cell in row.Cells)
                {
                    //Table cell is derived from (also a) TextBody
                    //Reusing the code meant for iterating TextBody
                    IterateTextBody(cell);
                }
            }
        }
        public ActionResult About()
        {
            ViewBag.Message = "Your application description page.";

            return View();
        }

        public ActionResult Contact()
        {
            ViewBag.Message = "Your contact page.";

            return View();
        }
    }
}